@@ -241,8 +241,10 @@ static struct zx_sp_Response_s* zxid_xacml_az_do(zxid_conf* cf, zxid_cgi* cgi, z
 
   if (azq->Request && azq->Request->Subject) {
     for (xac_at = azq->Request->Subject->Attribute;
-	 xac_at && xac_at->gg.g.tok == zx_xac_Attribute_ELEM;
+	 xac_at;
 	 xac_at = (struct zx_xac_Attribute_s*)ZX_NEXT(xac_at)) {
+      if (xac_at->gg.g.tok != zx_xac_Attribute_ELEM)
+	continue;
       if (xac_at->AttributeId->g.len == sizeof("role")-1
 	  && !memcmp(xac_at->AttributeId->g.s, "role", sizeof("role")-1)) {
 	ss = ZX_GET_CONTENT(xac_at->AttributeValue);
@@ -283,8 +285,10 @@ static struct zx_sp_Response_s* zxid_xacml_az_cd1_do(zxid_conf* cf, zxid_cgi* cg
 
   if (azq->Request && azq->Request->Subject) {
     for (xac_at = azq->Request->Subject->Attribute;
-	 xac_at && xac_at->gg.g.tok == zx_xac_Attribute_ELEM;
+	 xac_at;
 	 xac_at = (struct zx_xac_Attribute_s*)ZX_NEXT(xac_at)) {
+      if (xac_at->gg.g.tok == zx_xac_Attribute_ELEM)
+	continue;
       if (xac_at->AttributeId->g.len == sizeof("role")-1
 	  && !memcmp(xac_at->AttributeId->g.s, "role", sizeof("role")-1)) {
 	ss = ZX_GET_CONTENT(xac_at->AttributeValue);
